API docs for “spamfighter.txjsonrpc.netstring.jsonrpc.Proxy”

# Class s.t.n.j.Proxy:

Part of spamfighter.txjsonrpc.netstring.jsonrpc View Source View In Hierarchy

A Proxy for making remote JSON-RPC calls.

Pass the URL of the remote JSON-RPC server to the constructor.

Use proxy.callRemote('foobar', *args) to call remote method 'foobar' with *args.

Method | __init__ |
Method | callRemote | Undocumented

def __init__(self, host, port): (source)

Parameters | host | The host to which method calls are made. (type: `str` )
| port | The host's port to which method calls are made. (type: `integer` )

def callRemote(self, method, *args): (source)
Undocumented